@@ -516,6 +516,7 @@ MOS_STATUS CodecHalDecodeScalability_InitScalableParams_G12(
         bCanEnableRealTile = bCanEnableRealTile && pInitParams->bIsTileEnabled && (pInitParams->u8NumTileColumns > 1) &&
             (pInitParams->u8NumTileColumns <= u8MaxTileColumn) && (pInitParams->u8NumTileRows <= HEVC_NUM_MAX_TILE_ROW) &&
             pInitParams->bHasSubsetParams;
+        
         if (bCanEnableRealTile)
         {
             pScalabilityState->bIsRtMode = true;
@@ -894,6 +895,7 @@ MOS_STATUS CodecHalDecodeScalability_ReadCSEngineIDReg_G12(
         pDecodeStatusBuf->m_csEngineIdOffset + sizeof(uint32_t)* ucPhaseIndex +
         sizeof(uint32_t) * 2;
 
+    MOS_ZeroMemory(&StoreRegParams, sizeof(StoreRegParams));
     StoreRegParams.presStoreBuffer = &pDecodeStatusBuf->m_statusBuffer;
     StoreRegParams.dwOffset = dwOffset;
     StoreRegParams.dwRegister = pMmioRegisters->csEngineIdOffset;
@@ -1365,7 +1367,7 @@ MOS_STATUS CodecHalDecodeScalability_SetSfcState(
         {
             const uint32_t one_by_sf_fraction_precision = 19;
             const uint32_t beta_precision = 5;
-            uint32_t xPhaseShift = MOS_CLAMP_MIN_MAX(MOS_F_ROUND((((double)srcRegion->m_width / dstRegion->m_width - 1.0) / 2.0) * 524288.0F), -(1 << (4 + 19)), ((1 << (4 + 19)) - 1));
+            double xPhaseShift = MOS_CLAMP_MIN_MAX(MOS_F_ROUND((((double)srcRegion->m_width / dstRegion->m_width - 1.0) / 2.0) * 524288.0F), -(1 << (4 + 19)), ((1 << (4 + 19)) - 1));
 
             double tempDestCntx = (((double)scalabilityState->dstXLandingCount * (double)oneBySf) + xPhaseShift);
             if (tempDestCntx < 0)
@@ -1587,6 +1589,11 @@ bool CodecHalDecodeScalability_DecideEnableScala_G12(
     {
         bEnableScala = true;
     }
+    else if(MEDIA_IS_SKU(pScalState->pHwInterface->GetSkuTable(), FtrVirtualTileScalabilityDisable))
+    {
+        bEnableScala = false;
+        CODECHAL_DECODE_NORMALMESSAGE(" Disable VT Scalability according to platform SKU");
+    }
     else
     {
         // NonRextFormat && >=5k - VT Scalability
