@@ -1145,10 +1145,6 @@ MOS_STATUS GpuContextSpecific::SubmitCommandBuffer(
             {
                 execFlag = I915_EXEC_BSD | I915_EXEC_BSD_RING2;
             }
-            else if ((gpuNode == MOS_GPU_NODE_BLT))
-            {
-                execFlag = I915_EXEC_BLT;
-            }
             else
             {
                 MOS_OS_ASSERTMESSAGE("Invalid gpuNode.");
