@@ -30,9 +30,7 @@
 #include "encode_av1_brc.h"
 #include "encode_av1_vdenc_packet.h"
 #include "encode_av1_vdenc_lpla_enc.h"
-#if _MEDIA_RESERVED
 #include "encode_av1_scc.h"
-#endif
 
 namespace encode
 {
@@ -115,11 +113,19 @@ namespace encode
             {
                 // VDEnc read batch buffer (input for HuC FW)
                 allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(m_hwInterface->m_vdencReadBatchBufferSize, CODECHAL_PAGE_SIZE);
-                allocParamsForBufferLinear.pBufName = "VDENC Read Batch Buffer";
+                allocParamsForBufferLinear.pBufName = "VDENC Read Origin Batch Buffer";
                 allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_WRITE;
                 allocatedbuffer                     = m_allocator->AllocateResource(allocParamsForBufferLinear, true);
                 ENCODE_CHK_NULL_RETURN(allocatedbuffer);
-                m_vdencReadBatchBuffer[k][i] = *allocatedbuffer;
+                m_vdencReadBatchBufferOrigin[k][i] = *allocatedbuffer;
+
+                // VDEnc read batch buffer (input for HuC FW)
+                allocParamsForBufferLinear.dwBytes      = MOS_ALIGN_CEIL(m_hwInterface->m_vdencReadBatchBufferSize, CODECHAL_PAGE_SIZE);
+                allocParamsForBufferLinear.pBufName     = "VDENC Read TU7 Batch Buffer";
+                allocParamsForBufferLinear.ResUsageType = MOS_HW_RESOURCE_USAGE_ENCODE_INTERNAL_WRITE;
+                allocatedbuffer                         = m_allocator->AllocateResource(allocParamsForBufferLinear, true);
+                ENCODE_CHK_NULL_RETURN(allocatedbuffer);
+                m_vdencReadBatchBufferTU7[k][i] = *allocatedbuffer;
 
                 // BRC update DMEM
                 allocParamsForBufferLinear.dwBytes = MOS_ALIGN_CEIL(m_vdencBrcUpdateDmemBufferSize, CODECHAL_CACHELINE_SIZE);
@@ -156,8 +162,27 @@ namespace encode
 
         ENCODE_CHK_NULL_RETURN(m_basicFeature);
         ENCODE_CHK_NULL_RETURN(m_basicFeature->m_recycleBuf);
+        ENCODE_CHK_NULL_RETURN(m_basicFeature->m_av1PicParams);
+        ENCODE_CHK_NULL_RETURN(m_basicFeature->m_av1SeqParams);
+
+        ENCODE_CHK_STATUS_RETURN(ConstructBatchBufferHuCBRC(&m_vdencReadBatchBufferOrigin[m_pipeline->m_currRecycledBufIdx][m_pipeline->GetCurrentPass()]));
+    
+        if (m_basicFeature->m_av1PicParams->AdaptiveTUEnabled != 0)
+        {
+            auto original_TU              = m_basicFeature->m_targetUsage;
+            m_basicFeature->m_targetUsage = m_basicFeature->m_av1SeqParams->TargetUsage = 7;
+
+            auto sccFeature = dynamic_cast<Av1Scc *>(m_featureManager->GetFeature(Av1FeatureIDs::av1Scc));
+            ENCODE_CHK_NULL_RETURN(sccFeature);
+            bool original_Palette = sccFeature->IsPaletteEnabled();
+            sccFeature->SetPalette(false);
+            m_basicFeature->m_av1PicParams->PicFlags.fields.PaletteModeEnable           = 0;
+            ENCODE_CHK_STATUS_RETURN(ConstructBatchBufferHuCBRC(&m_vdencReadBatchBufferTU7[m_pipeline->m_currRecycledBufIdx][m_pipeline->GetCurrentPass()]));
+            m_basicFeature->m_targetUsage = m_basicFeature->m_av1SeqParams->TargetUsage = original_TU;
+            sccFeature->SetPalette(original_Palette);
+            m_basicFeature->m_av1PicParams->PicFlags.fields.PaletteModeEnable = original_Palette;
+        }        
 
-        ENCODE_CHK_STATUS_RETURN(ConstructBatchBufferHuCBRC(&m_vdencReadBatchBuffer[m_pipeline->m_currRecycledBufIdx][m_pipeline->GetCurrentPass()]));
         ENCODE_CHK_STATUS_RETURN(ConstructPakInsertHucBRC(&m_vdencPakInsertBatchBuffer[m_pipeline->m_currRecycledBufIdx]));
 
         bool firstTaskInPhase = packetPhase & firstPacket;
@@ -275,6 +300,14 @@ namespace encode
         /*----Group4----*/
         slbData.avpPicStateOffset = (uint16_t)constructedCmdBuf.iOffset;
         ENCODE_CHK_STATUS_RETURN(AddAvpPicStateBaseOnTile(constructedCmdBuf, slbData));
+
+        /*----Group5----*/
+        if (m_basicFeature->m_av1PicParams->PicFlags.fields.PaletteModeEnable || m_basicFeature->m_av1PicParams->AdaptiveTUEnabled)
+        {
+            slbData.vdencTileSliceStateOffset = (uint16_t)constructedCmdBuf.iOffset;
+            ENCODE_CHK_STATUS_RETURN(AddVdencTileSliceBaseOnTile(constructedCmdBuf, slbData));
+        }
+
         slbData.slbSize = (uint16_t)constructedCmdBuf.iOffset - slbData.avpSegmentStateOffset;
 
         RUN_FEATURE_INTERFACE_NO_RETURN(Av1Brc, Av1FeatureIDs::av1BrcFeature, SetSLBData, slbData);
@@ -322,6 +355,7 @@ namespace encode
         bool firstTileInGroup = false;
         uint32_t tileGroupIdx = 0;
         RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetTileRowColumns, numTileRows, numTileColumns);
+        slbData.tileNum = numTileRows * numTileColumns;
 
         for (uint32_t tileRow = 0; tileRow < numTileRows; tileRow++)
         {
@@ -332,12 +366,12 @@ namespace encode
 #if _MEDIA_RESERVED
                 RUN_FEATURE_INTERFACE_RETURN(Av1Scc, Av1FeatureIDs::av1Scc, UpdateIBCStatusForCurrentTile);
 #endif
-                if (firstTileInGroup)
+                if (tileRow == 0 && tileCol == 0)
                 {
                     SETPAR_AND_ADDCMD(AVP_PIC_STATE, m_avpItf, &cmdBuffer);
                     ENCODE_CHK_STATUS_RETURN(AddBBEnd(m_miItf, cmdBuffer));
                 }
-                else
+                if (!firstTileInGroup)
                 {
                     slbData.avpPicStateCmdNum = 2;
                     slbData.secondAvpPicStateOffset = (uint16_t)cmdBuffer.iOffset;
@@ -352,6 +386,44 @@ namespace encode
                 break;
             }
         }
+
+        // Add MI_NOOPs to align with CODECHAL_CACHELINE_SIZE
+        uint32_t size = (MOS_ALIGN_CEIL(cmdBuffer.iOffset, CODECHAL_CACHELINE_SIZE) - cmdBuffer.iOffset) / sizeof(uint32_t);
+        for (uint32_t i = 0; i < size; i++)
+            ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_NOOP)(&cmdBuffer));
+
+        return MOS_STATUS_SUCCESS;
+    }
+
+    MOS_STATUS Av1BrcUpdatePkt::AddVdencTileSliceBaseOnTile(MOS_COMMAND_BUFFER& cmdBuffer, SlbData& slbData)
+    {
+        ENCODE_FUNC_CALL();
+
+        uint16_t numTileColumns = 1;
+        uint16_t numTileRows = 1;
+        RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, GetTileRowColumns, numTileRows, numTileColumns);
+
+        auto& par = m_vdencItf->MHW_GETPAR_F(VDENC_HEVC_VP9_TILE_SLICE_STATE)();
+        par = {};
+
+        for (uint32_t tileRow = 0; tileRow < numTileRows; tileRow++)
+        {
+            for (uint32_t tileCol = 0; tileCol < numTileColumns; tileCol++)
+            {
+                RUN_FEATURE_INTERFACE_RETURN(Av1EncodeTile, Av1FeatureIDs::encodeTile, SetCurrentTile, tileRow, tileCol, m_pipeline);
+                auto tileIdx = tileRow * numTileColumns + tileCol;
+
+                m_basicFeature->m_vdencTileSliceStart[tileIdx] = cmdBuffer.iOffset;
+                SETPAR_AND_ADDCMD(VDENC_HEVC_VP9_TILE_SLICE_STATE, m_vdencItf, &cmdBuffer);
+                ENCODE_CHK_STATUS_RETURN(AddBBEnd(m_miItf, cmdBuffer));
+
+                // Add MI_NOOPs to align with CODECHAL_CACHELINE_SIZE
+                uint32_t size = (MOS_ALIGN_CEIL(cmdBuffer.iOffset, CODECHAL_CACHELINE_SIZE) - cmdBuffer.iOffset) / sizeof(uint32_t);
+                for (uint32_t i = 0; i < size; i++)
+                    ENCODE_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_NOOP)(&cmdBuffer));
+            }
+        }
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -409,14 +481,14 @@ namespace encode
             uint32_t nalNum = 0;
             for (uint32_t i = 0; i < MAX_NUM_OBU_TYPES && m_basicFeature->m_nalUnitParams[i]->uiSize > 0; i++)
             {
-                nalNum = i;
+                nalNum++;
             }
 
             params.bsBuffer             = &m_basicFeature->m_bsBuffer;
             params.endOfHeaderInsertion = false;
 
             // Support multiple packed header buffer
-            for (uint32_t i = 0; i <= nalNum; i++)
+            for (uint32_t i = 0; i < nalNum; i++)
             {
                 uint32_t nalUnitSize   = m_basicFeature->m_nalUnitParams[i]->uiSize;
                 uint32_t nalUnitOffset = m_basicFeature->m_nalUnitParams[i]->uiOffset;
@@ -427,7 +499,7 @@ namespace encode
                 {
                     params.bitSize    = nalUnitSize * 8;
                     params.offset     = nalUnitOffset;
-                    params.lastHeader = !tgOBUValid && (i == nalNum);
+                    params.lastHeader = !tgOBUValid && (i+1 == nalNum);
 
                     m_avpItf->MHW_ADDCMD_F(AVP_PAK_INSERT_OBJECT)(cmdBuffer);
                     m_osInterface->pfnAddCommand(cmdBuffer, GetExtraData(), GetExtraSize());
@@ -455,11 +527,15 @@ namespace encode
 
         ENCODE_CHK_STATUS_RETURN(DumpRegion(0, "_BrcHistory", true, hucRegionDumpUpdate, 6080));
         ENCODE_CHK_STATUS_RETURN(DumpRegion(1, "_VdencStats", true, hucRegionDumpUpdate, 48*4));
-        ENCODE_CHK_STATUS_RETURN(DumpRegion(3, "_InputSLBB", true, hucRegionDumpUpdate, 300*4));
+        ENCODE_CHK_STATUS_RETURN(DumpRegion(3, "_InputSLBB_Origin", true, hucRegionDumpUpdate, 600*4));
         ENCODE_CHK_STATUS_RETURN(DumpRegion(5, "_ConstData", true, hucRegionDumpUpdate, MOS_ALIGN_CEIL(m_vdencBrcConstDataBufferSize, CODECHAL_PAGE_SIZE)));
         ENCODE_CHK_STATUS_RETURN(DumpRegion(7, "_PakMmio", true, hucRegionDumpUpdate, 16*4));
         ENCODE_CHK_STATUS_RETURN(DumpRegion(8, "_InputPakInsert", true, hucRegionDumpUpdate, 100));
         ENCODE_CHK_STATUS_RETURN(DumpRegion(10, "_InputCdfTable", true, hucRegionDumpUpdate, 4 * MOS_ALIGN_CEIL(m_basicFeature->m_cdfMaxNumBytes, CODECHAL_CACHELINE_SIZE)));
+        if (m_basicFeature->m_av1PicParams->AdaptiveTUEnabled != 0)
+        {
+            ENCODE_CHK_STATUS_RETURN(DumpRegion(12, "_InputSLBB_TU7", true, hucRegionDumpUpdate, 600 * 4));
+        }
 
         return MOS_STATUS_SUCCESS;
     }
@@ -470,7 +546,7 @@ namespace encode
 
         ENCODE_CHK_STATUS_RETURN(DumpRegion(0, "_BrcHistory", false, hucRegionDumpUpdate, 6080));
         ENCODE_CHK_STATUS_RETURN(DumpRegion(4, "_BrcData", false, hucRegionDumpUpdate, 32));
-        ENCODE_CHK_STATUS_RETURN(DumpRegion(6, "_OutputSLBB", false, hucRegionDumpUpdate, 300 * 4));
+        ENCODE_CHK_STATUS_RETURN(DumpRegion(6, "_OutputSLBB", false, hucRegionDumpUpdate, 600 * 4));
         ENCODE_CHK_STATUS_RETURN(DumpRegion(9, "_OutputPakInsert", false, hucRegionDumpUpdate, 100));
         ENCODE_CHK_STATUS_RETURN(DumpRegion(11, "_OutputCdfTable", false, hucRegionDumpUpdate, MOS_ALIGN_CEIL(m_basicFeature->m_cdfMaxNumBytes, CODECHAL_CACHELINE_SIZE)));
 
@@ -551,8 +627,8 @@ namespace encode
         // Region 1 - VDenc Stats Buffer (Input)
         params.regionParams[1].presRegion = resTileBasedStatisticsBuffer;
         params.regionParams[1].dwOffset   = offset;
-        // Region 3 - Input SLB Buffer (Input)
-        params.regionParams[3].presRegion = const_cast<PMOS_RESOURCE>(&m_vdencReadBatchBuffer[bufIdx][currentPass]);
+        // Region 3 - Input SLB Buffer (Input Origin)
+        params.regionParams[3].presRegion = const_cast<PMOS_RESOURCE>(&m_vdencReadBatchBufferOrigin[bufIdx][currentPass]);
         // Region 4 - BRC Data for next frame's width/height - (Output)
         params.regionParams[4].presRegion = resBrcDataBuffer;
         params.regionParams[4].isWritable = true;
@@ -573,7 +649,19 @@ namespace encode
         // Region 11 - CDF (output)
         params.regionParams[11].presRegion = m_basicFeature->m_defaultCdfBufferInUse;
         params.regionParams[11].isWritable = true;
-
+        // Region 12 - Input SLB Buffer (Input TU7)
+        if (m_basicFeature->m_av1PicParams->AdaptiveTUEnabled != 0)
+        {
+            params.regionParams[12].presRegion = const_cast<PMOS_RESOURCE>(&m_vdencReadBatchBufferTU7[bufIdx][currentPass]);
+        }
+        
+        if (m_basicFeature->m_av1SeqParams->LookaheadDepth && m_basicFeature->m_laDataBufferEnabled)
+        {
+            ENCODE_CHK_NULL_RETURN(m_basicFeature->m_LaDataBuffer);
+            ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnSkipResourceSync(m_basicFeature->m_LaDataBuffer));
+            params.regionParams[13].presRegion = m_basicFeature->m_LaDataBuffer;
+        }
+        
         return MOS_STATUS_SUCCESS;
     }
 
